@@ -91,12 +91,15 @@ tracker_seccomp_init (void)
 	/* Basic filesystem access */
 	ALLOW_RULE (fstat);
 	ALLOW_RULE (fstat64);
+	ALLOW_RULE (fstatat64);
+	ALLOW_RULE (newfstatat);
 	ALLOW_RULE (stat);
 	ALLOW_RULE (stat64);
 	ALLOW_RULE (statfs);
 	ALLOW_RULE (statfs64);
 	ALLOW_RULE (lstat);
 	ALLOW_RULE (lstat64);
+	ALLOW_RULE (statx);
 	ALLOW_RULE (access);
 	ALLOW_RULE (getdents);
 	ALLOW_RULE (getdents64);
